Project description
---------------------

teamscritique provides library for analyzing audio file's sentiment (sad or happy). To analyze sentiment in audio file, simply go to python and do:

    >>> import teamscritique
    >>> teamscritique.analyze(filelocation)